//
//  ViewController.m
//  ex_NSUserDefaults
//
//  Created by yoshiyuki oshige on 2013/09/09.
//  Copyright (c) 2013年 yoshiyuki. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()
// スライダーとラベルをアウトレット接続してプロパティ宣言する
@property (weak, nonatomic) IBOutlet UISlider *mySlider;
@property (weak, nonatomic) IBOutlet UILabel *sliderLabel;
@property (weak, nonatomic) IBOutlet UISwitch *mySwitch;
@property (weak, nonatomic) IBOutlet UILabel *switchLabel;

// スライダーのChangedイベントアクションと接続する
- (IBAction)changedSlider:(UISlider *)sender;
// スイッチのChangedイベントアクションと接続する
- (IBAction)changedSwitch:(UISwitch *)sender;

// 設定を保存する
- (void)saveDefault;

@end

@implementation ViewController

// アプリ起動時に実行される
+ (void) initialize
{
    // 初回起動時の初期値データ
    NSMutableDictionary *appDefaults = [[NSMutableDictionary alloc] init];
    [appDefaults setValue:@"0.75" forKey:@"sliderValue"];
    [appDefaults setValue:@"YES" forKey:@"switchValue"];
    // ユーザーデフォルトの初期値に設定する
    NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
    [userDefaults registerDefaults:appDefaults];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
}

// ビューが表示される前にスライダーとスイッチをセットする
- (void)viewWillAppear:(BOOL)animated
{
    // 保存されているNSUserDefaults オブジェクトを読み込む
    NSUserDefaults *myDefaults = [NSUserDefaults standardUserDefaults];
    // 保存しておいた値にスライダーをセットする
    _mySlider.value = [myDefaults floatForKey:@"sliderValue"];
    _sliderLabel.text = [NSString stringWithFormat:@"%.2f", _mySlider.value];
    // 保存しておいた値にスイッチをセットする
    _mySwitch.on = [myDefaults boolForKey:@"switchValue"];
    if (_mySwitch.on) {
        _switchLabel.text = @"ON";
    } else {
        _switchLabel.text = @"OFF";
    }
}

// 設定値をユーザーデフォルトに保存する
- (void)saveDefault
{
    NSUserDefaults *myDefaults = [NSUserDefaults standardUserDefaults];
    // スライダーの数値をユーザーデフォルトに保存する
    [myDefaults setFloat:_mySlider.value forKey:@"sliderValue"];
    // スイッチのBOOL値をユーザーデフォルトに保存する
    [myDefaults setBool:_mySwitch.on forKey:@"switchValue"];
    // ユーザーデフォルトに即座に保存する
    [myDefaults synchronize];
}

// スライダーの値をラベルに表示する
- (IBAction)changedSlider:(UISlider *)sender {
    _sliderLabel.text = [NSString stringWithFormat:@"%.2f", sender.value];
    // 値を保存する
    [self saveDefault];
}

//　スイッチの値をラベルに表示する
- (IBAction)changedSwitch:(UISwitch *)sender {
    if (_mySwitch.on) {
        _switchLabel.text = @"ON";
    } else {
        _switchLabel.text = @"OFF";
    }
    // 値を保存する
    [self saveDefault];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
