//
//  ViewController.m
//  ex_NSString_writeToFile ver2
//
//  Created by yoshiyuki oshige on 2013/09/11.
//  Copyright (c) 2013年 yoshiyuki. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()
{
    //テキストビューのオリジナルのframeサイズ
    CGRect orginalFrame;
}

//テキストビューをアウトレット接続してプロパティ宣言する
@property (weak, nonatomic) IBOutlet UITextView *myTextView;

//ボタンをアクション接続してメソッド宣言する
- (IBAction)editDone:(id)sender;
- (IBAction)editCancel:(id)sender;

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// ファイルを読み込んでテキストに表示する
    [self loadFile];
    
    // 通知センターのオブジェクトを作る
    NSNotificationCenter *notification = [NSNotificationCenter defaultCenter];
    // 通知センターにキーボード出現の監視を登録する
    [notification addObserver:self
                     selector:@selector(keyboardDidShow:)
                         name:UIKeyboardDidShowNotification
                       object:nil];
    // 通知センターにキーボード退出の監視を登録する
    [notification addObserver:self
                     selector:@selector(keyboardDidHide:)
                         name:UIKeyboardDidHideNotification
                       object:nil];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

// ビューが表示された
- (void)viewDidAppear:(BOOL)animated
{
    // テキストビューのオリジナルのframe サイズを保存する
    orginalFrame = _myTextView.frame;
}


// 通知センターからキーボードの出現が通知された
- (void)keyboardDidShow:(NSNotification *)notification
{
    NSLog(@"textViewFrame.size.height---- %f", _myTextView.frame.size.height);
    // 出現したキーボードのサイズを調べる
    NSDictionary *infoDic = [notification userInfo];
    CGRect keyboardFrame = [infoDic[UIKeyboardFrameEndUserInfoKey] CGRectValue];
    // テキストビューのサイズをキーボードの上に残った空きスペースのサイズに変更する
    CGRect textViewFrame = _myTextView.frame;
    textViewFrame.size.height = orginalFrame.size.height - keyboardFrame.size.height;
    _myTextView.frame = textViewFrame;
}

// 通知センターからキーボードの退出が通知された
- (void)keyboardDidHide:(NSNotificationCenter *)notification
{
    // テキストビューのframe サイズを元のサイズに戻す（画面一杯に広げる）
    _myTextView.frame = orginalFrame;
}

//Done ボタンをタップして実行
- (IBAction)editDone:(id)sender {
    // テキストを保存する
    [self saveFile];
    // キーボードを下げる
    [self.view endEditing:YES];
}

//Cancel ボタンをタップして実行
- (IBAction)editCancel:(id)sender {
    // ファイルを読み込んでテキストを元に戻す
    [self loadFile];
    // キーボードを下げる
    [self.view endEditing:YES];
}

// ファイルを読み込んでテキストを表示する
- (void)loadFile
{
    // 読み込むファイルパスを作成
    NSString *filePath = [NSHomeDirectory() stringByAppendingPathComponent:@"/Documents/note.txt"];
    // ファイルが存在するかどうかを確かめて読み込む
    NSFileManager *fileManager = [NSFileManager defaultManager];
    if ([fileManager fileExistsAtPath:filePath]) {
        // ファイルからテキストを読み込んでテキストビューに表示する
        _myTextView.text = [NSString stringWithContentsOfFile:filePath
                                                     encoding:NSUTF8StringEncoding
                                                        error:NULL];
    }else{
        NSLog(@" ファイルがありません.");
        _myTextView.text = nil;
    }
}

// テキストの内容をファイルに保存する
- (void)saveFile
{
    // 書き込むファイルパスを作成
    NSString *filePath = [NSHomeDirectory() stringByAppendingPathComponent:@"/Documents/note.txt"];
    // テキストビューのテキストをファイルに保存する
    [_myTextView.text writeToFile:filePath
                       atomically:YES
                         encoding:NSUTF8StringEncoding
                            error:NULL];
}

@end

